import { Component, OnInit, ViewChild } from '@angular/core';
import {
  IonHeader,
  IonToolbar,
  IonTitle,
  IonContent,
  IonGrid,
  IonRow,
  IonCol,
  IonCard,
  IonButton,
  IonInput,
  IonButtons, 
  IonMenuButton,
} from '@ionic/angular/standalone';
import { ColumnMode, DatatableComponent, NgxDatatableModule } from '@swimlane/ngx-datatable';
import { PengukuranService } from '../services/pengukuran.service';
import { Storage } from '@ionic/storage-angular';

@Component({
  selector: 'app-tabel',
  templateUrl: './tabel.page.html',
  styleUrls: ['./tabel.page.scss'],
  standalone: true,
  imports: [
    IonHeader,
    IonToolbar,
    IonTitle,
    IonContent,
    IonGrid,
    IonRow,
    IonCol,
    IonCard,
    IonButton,
    IonInput,
    NgxDatatableModule,
    IonButtons,
    IonMenuButton
  ],
})
export class TabelPage implements OnInit {

  @ViewChild(DatatableComponent) table!: DatatableComponent;
  ColumnMode = ColumnMode;
  loadingIndicator!: boolean;
  temp: any[] = [];
  rows: any[] = [];
  dummy: any;
  

  constructor(private pengukuranService: PengukuranService, private storage: Storage,) { }

  async ngOnInit() {
    await this.storage.create();
    this.getPengukuranData();
    this.loadingIndicator = true;
    this.dummy = [
        {
          "id": 4,
          "berat_badan": 1,
          "tinggi_badan": 2,
          "imt": 3,
          "lingkar_perut": 16,
          "tekanan_darah_diastole": 4,
          "tekanan_darah_sistole": 5,
          "frekuensi_nafas": 6,
          "nadi": 7,
          "kadar_gula_darah": 8,
          "waktu_pengambilan_gula_darah": "pagi",
          "kolesterol_total": 11,
          "kolesterol_ldl": 10,
          "kolesterol_hdl": 9,
          "trigliserida": 15,
          "kadar_hb": 12,
          "kadar_asam_urat": 13,
          "golongan_darah": "14",
          "kondisi_umum": "kondisi",
          "keluhan_perasaan": "keluhan",
          "created_at": "2024-05-15T12:37:35Z",
          "updated_at": "2024-05-15T12:37:35Z",
          "deleted_at": null,
          "identitas_id": 8
        },
        {
          "id": 5,
          "berat_badan": 3123,
          "tinggi_badan": 123,
          "imt": 412,
          "lingkar_perut": 45,
          "tekanan_darah_diastole": 244,
          "tekanan_darah_sistole": 34,
          "frekuensi_nafas": 234,
          "nadi": 34,
          "kadar_gula_darah": 42,
          "waktu_pengambilan_gula_darah": "pagi",
          "kolesterol_total": 2345,
          "kolesterol_ldl": 23,
          "kolesterol_hdl": 3424,
          "trigliserida": 534,
          "kadar_hb": 44,
          "kadar_asam_urat": 53,
          "golongan_darah": "45",
          "kondisi_umum": "kondisi",
          "keluhan_perasaan": "keluhan",
          "created_at": "2024-05-15T12:39:11Z",
          "updated_at": "2024-05-15T12:39:11Z",
          "deleted_at": null,
          "identitas_id": 8
        },
        {
          "id": 6,
          "berat_badan": 123,
          "tinggi_badan": 412,
          "imt": 312,
          "lingkar_perut": 20,
          "tekanan_darah_diastole": 23,
          "tekanan_darah_sistole": 54,
          "frekuensi_nafas": 34,
          "nadi": 234,
          "kadar_gula_darah": 234,
          "waktu_pengambilan_gula_darah": "makan",
          "kolesterol_total": 543,
          "kolesterol_ldl": 523,
          "kolesterol_hdl": 5234,
          "trigliserida": 24,
          "kadar_hb": 45,
          "kadar_asam_urat": 35,
          "golongan_darah": "2345",
          "kondisi_umum": "aman terkendali",
          "keluhan_perasaan": "perasaan",
          "created_at": "2024-05-15T12:41:39Z",
          "updated_at": "2024-05-15T12:41:39Z",
          "deleted_at": null,
          "identitas_id": 8
        }
      ]
    this.temp = [
      { id: 1, name: 'Austin', gender: 'Male', company: 'Swimlane' },
      { id: 2, name: 'Dany', gender: 'Male', company: 'KFC' },
      { id: 3, name: 'Molly', gender: 'Female', company: 'Burger King' },
      { id: 4, name: 'Austin', gender: 'Male', company: 'Swimlane' },
      { id: 5, name: 'Dany', gender: 'Male', company: 'KFC' },
      { id: 6, name: 'Molly', gender: 'Female', company: 'Burger King' },
      { id: 7, name: 'Austin', gender: 'Male', company: 'Swimlane' },
      { id: 8, name: 'Dany', gender: 'Male', company: 'KFC' },
      { id: 9, name: 'Molly', gender: 'Female', company: 'Burger King' },
      { id: 10, name: 'Austin', gender: 'Male', company: 'Swimlane' },
      { id: 11, name: 'Dany', gender: 'Male', company: 'KFC' },
      { id: 12, name: 'Molly', gender: 'Female', company: 'Burger King' },
    ];
    this.rows = [...this.dummy];
    this.loadingIndicator = false;
  }
  async getPengukuranData() {
    const idIdentitas = await this.storage.get('id_identitas');
    this.pengukuranService.getPengukuranByIdentitasId(idIdentitas).subscribe(
      (data: any) => {
        console.log('Data Pengukuran:', data);
      },
      (error: any) => {
        console.error('Error:', error);
      }
    );
  }
}